//
//  Test_mindot.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_mindot_h
#define BulletTest_Test_mindot_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_mindot(void);

#ifdef __cplusplus
}
#endif

#endif
